============
Contributors
============

* Aurelien REYSSET <aurelien.reysset@insa-toulouse.fr>
* Florent LUTZ <Florent.LUTZ2@isae-supaero.fr>
* Aitor BUSTEROS RAMOS <Aitor.BUSTEROS-RAMOS@student.isae-supaero.fr>
* Lucas REMOND <Lucas.REMOND@isae-supaero.fr>